SystemOrganization addCategory: #'FuelCompression-Tests'!

!PositionableStream class methodsFor: '*FuelCompression-instance creation' stamp: 'MartinDias 10/12/2011 18:35'!
on: aCollectionOrStream do: aBlock
	"Evaluates a block with a new stream based on the collection or stream. Answers the result of the block evaluation. Follows the style of FileStream>>fileNamed:do:."
	| aStream |
	aStream := self on: aCollectionOrStream.
	[ ^ aBlock value: aStream ] ensure: [ aStream close ]! !

FLSerializationTest subclass: #FLGZippedSerializationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelCompression-Tests'!

!FLGZippedSerializationTest methodsFor: 'tests' stamp: 'MartinDias 1/7/2012 00:32'!
assertSerializationEqualityOf: anObject

	| materializedObject testFileName |
	testFileName := 'gzippedTest.fuel.zip'.
	
	FileStream
		forceNewFileNamed: testFileName
		do: [ :stream | 
			GZipWriteStream 
				on: stream binary
				do: [ :gzipStream | 
					FLSerializer newDefault serialize: anObject on: gzipStream ] ].

	materializedObject := FileStream
		oldFileNamed: testFileName
		do: [ :stream | 
			GZipReadStream
				on: stream binary
				do: [ :gzipStream | (FLMaterializer newDefault materializeFrom: gzipStream) root ] ].

	self assert: anObject equals: materializedObject! !

!FLGZippedSerializationTest methodsFor: 'tests' stamp: 'MartinDias 9/27/2011 22:37'!
testByteArray

	self assertSerializationEqualityOf: #[1 2 3 4 5 6 7]! !

!FLGZippedSerializationTest methodsFor: 'tests' stamp: 'MartinDias 9/27/2011 22:45'!
testCompleteBinaryTree

	| aCollection numberOfLeafs |
	numberOfLeafs := 2 raisedTo: 13.
	aCollection := OrderedCollection new.
	1 to: numberOfLeafs do: [ :i | 
		aCollection add: (
			FLPair new 
				left: (2 * i); 
				right: (2 * i) + 1;
				yourself) ].
	
	[aCollection size > 1] 
		whileTrue: [
			aCollection := aCollection pairsCollect: [ :leftPair :rightPair | 
				FLPair new 
					left: leftPair;
					right: rightPair;
					yourself ] ].

	self assertSerializationEqualityOf: aCollection! !

!FLGZippedSerializationTest methodsFor: 'tests' stamp: 'MartinDias 9/27/2011 22:44'!
testPairs

	| pairs |
	pairs := (1 to: 1 << 14) 
		collect: [ :i | 
			FLPair new 
				left: i; 
				right: i+1;
				yourself ].

	self assertSerializationEqualityOf: pairs! !

!FLGZippedSerializationTest methodsFor: 'tests' stamp: 'MartinDias 9/27/2011 22:36'!
testString

	self assertSerializationEqualityOf: 'GZippppped'! !

!FLGZippedSerializationTest methodsFor: 'tests' stamp: 'MartinDias 12/9/2011 16:16'!
testWideString

	| anObject |
	anObject := OrderedCollection new.
	600 timesRepeat: [
	       anObject add: (WideString
	               streamContents: [ :stream |
	                       600 timesRepeat: [
	                               stream nextPut: (256 to: 1000) atRandom asCharacter ] ] ) ].

	self assertSerializationEqualityOf: anObject! !

!FLSerializationTest methodsFor: '*FuelCompression-stream-strategies' stamp: 'MartinDias 10/12/2011 18:42'!
useGzipInMemoryStream

	streamFactory := FLGZipStrategy newWithTarget: FLByteArrayStreamStrategy new! !

FLStreamStrategy subclass: #FLGZipStrategy
	instanceVariableNames: 'targetStrategy'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelCompression-Tests'!

!FLGZipStrategy class methodsFor: 'instance creation' stamp: 'MartinDias 10/12/2011 18:40'!
newWithTarget: aStreamStrategy

	^self basicNew
		initializeWith: aStreamStrategy;
		yourself
		! !

!FLGZipStrategy methodsFor: 'initialize-release' stamp: 'MartinDias 10/12/2011 18:41'!
initializeWith: aStreamStrategy

	self initialize.
	targetStrategy := aStreamStrategy.! !

!FLGZipStrategy methodsFor: 'reading' stamp: 'MartinDias 10/12/2011 18:38'!
readStreamDo: aValuable
	"Evaluates the argument with a read stream. Answers the result."
	
	targetStrategy readStreamDo: [:aStream |
		^ GZipReadStream on: aStream do: aValuable]
! !

!FLGZipStrategy methodsFor: 'writing' stamp: 'MartinDias 10/12/2011 18:36'!
writeStreamDo: aValuable
	"Evaluates the argument with a write stream. Answers the result."
	
	targetStrategy writeStreamDo: [:aStream |
		^ GZipWriteStream on: aStream do: aValuable]
! !
